ChromaSubsampling

Enum ChromaSubsampling 

#[non_exhaustive]
pub enum ChromaSubsampling { None, HalfHorizontal, Quarter, HalfVertical, }
YCbCr chroma subsampling (spatial resolution).

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


None

4:4:4 - No subsampling (full chroma resolution, best quality, largest files)



HalfHorizontal

4:2:2 - Half horizontal resolution



Quarter

4:2:0 - Quarter resolution (half each direction, most common)



HalfVertical

4:4:0 - Half vertical resolution

Implementations

Source

impl ChromaSubsampling

pub const fn h_factor(&self) -> u8

Horizontal subsampling factor (1 or 2).

pub const fn v_factor(&self) -> u8

Vertical subsampling factor (1 or 2).

pub const fn h_samp_factor_luma(self) -> u8

Returns the horizontal sampling factor for luma.

This is the luma block count in horizontal direction per MCU. Returns 1 for 4:4:4/4:4:0, returns 2 for 4:2:0/4:2:2.

pub const fn v_samp_factor_luma(self) -> u8

Returns the vertical sampling factor for luma.

This is the luma block count in vertical direction per MCU. Returns 1 for 4:4:4/4:2:2, returns 2 for 4:2:0/4:4:0.

pub const fn mcu_size(self) -> usize

Returns the MCU (Minimum Coded Unit) size for this subsampling mode.

  • 8 for 4:4:4 (no subsampling)
  • 16 for modes with 2x sampling (4:2:0, 4:2:2, 4:4:0)